@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
 """
 Functions that operate on lists, dicts, and other objects.
 
 .. versionadded:: 1.0.0
 """
 
-from __future__ import absolute_import
-
 import copy
 from functools import partial
 import math
@@ -14,8 +11,7 @@ import re
 
 import pydash as pyd
 
-from ._compat import iteritems, string_types, text_type
-from .helpers import NoValue, base_get, base_set, callit, getargcount, iterator, iteriteratee
+from .helpers import UNSET, base_get, base_set, callit, getargcount, iterator, iteriteratee
 from .utilities import PathToken, to_path, to_path_tokens
 
 
@@ -152,7 +148,7 @@ def assign_with(obj, *sources, **kwargs):
     for source in sources:
         source = source.copy()
 
-        for key, value in iteritems(source):
+        for key, value in source.items():
             if customizer:
                 val = callit(customizer, obj.get(key), value, key, obj, source, argcount=argcount)
                 if val is not None:
@@ -313,7 +309,7 @@ def defaults(obj, *sources):
     .. versionadded:: 1.0.0
     """
     for source in sources:
-        for key, value in iteritems(source):
+        for key, value in source.items():
             obj.setdefault(key, value)
 
     return obj
@@ -477,8 +473,6 @@ def get(obj, path, default=None):
     Args:
         obj (list|dict|Sequence|Mapping): Object to process.
         path (str|list): List or ``.`` delimited string of path describing path.
-
-    Keyword Arguments:
         default (mixed): Default value to return if path doesn't exist. Defaults to ``None``.
 
     Returns:
@@ -521,7 +515,7 @@ def get(obj, path, default=None):
     .. versionchanged:: 4.7.6
         Fixed bug where getattr is used on Mappings and Sequence in Python 3.5+
     """
-    if default is NoValue:
+    if default is UNSET:
         # When NoValue given for default, then this method will raise if path is not present in obj.
         sentinel = default
     else:
@@ -580,7 +574,7 @@ def has(obj, path):
         Removed aliases ``deep_has`` and ``has_path``.
     """
     try:
-        get(obj, path, default=NoValue)
+        get(obj, path, default=UNSET)
         exists = True
     except (KeyError, IndexError, TypeError, ValueError):
         exists = False
@@ -627,6 +621,7 @@ def invert_by(obj, iteratee=None):
 
     Args:
         obj (dict): Object to invert.
+        iteratee (mixed): Iteratee applied per iteration.
 
     Returns:
         dict: Inverted dict.
@@ -776,7 +771,7 @@ def map_values(obj, iteratee=None):
     return {key: result for result, _, key, _ in iteriteratee(obj, iteratee)}
 
 
-def map_values_deep(obj, iteratee=None, property_path=NoValue):
+def map_values_deep(obj, iteratee=None, property_path=UNSET):
     """
     Map all non-object values in `obj` with return values from `iteratee`. The iteratee is invoked
     with two arguments: ``(obj_value, property_path)`` where ``property_path`` contains the list of
@@ -785,6 +780,7 @@ def map_values_deep(obj, iteratee=None, property_path=NoValue):
     Args:
         obj (list|dict): Object to map.
         iteratee (callable): Iteratee applied to each value.
+        property_path (mixed, optional): Path key(s) to access.
 
     Returns:
         mixed: The modified object.
@@ -856,6 +852,9 @@ def merge(obj, *sources):
 
     .. versionchanged:: 4.0.0
         Moved iteratee argument to :func:`merge_with`.
+
+    .. versionchanged:: 4.9.3
+        Fixed regression in v4.8.0 that caused exception when `obj` was ``None``.
     """
     return merge_with(obj, *sources)
 
@@ -892,40 +891,50 @@ def merge_with(obj, *sources, **kwargs):
         True
 
     .. versionadded:: 4.0.0
-    """
-    sources = list(sources)
-    _clone = kwargs.get("_clone", True)
-    iteratee = kwargs.get("iteratee")
-    setter = kwargs.get("_setter", base_set)
 
-    if iteratee is None and callable(sources[-1]):
+    .. versionchanged:: 4.9.3
+        Fixed regression in v4.8.0 that caused exception when `obj` was ``None``.
+    """
+    if obj is None:
+        return None
+
+    sources = list(sources)
+    iteratee = kwargs.pop("iteratee", None)
+
+    if iteratee is None and sources and callable(sources[-1]):
         iteratee = sources.pop()
 
+    sources = [copy.deepcopy(source) for source in sources]
+
     if callable(iteratee):
-        argcount = getargcount(iteratee, maxargs=5)
-        cbk = partial(callit, iteratee, argcount=argcount)
+        iteratee = partial(callit, iteratee, argcount=getargcount(iteratee, maxargs=5))
     else:
-        cbk = None
+        iteratee = None
+
+    return _merge_with(obj, *sources, iteratee=iteratee, **kwargs)
+
+
+def _merge_with(obj, *sources, **kwargs):
+    iteratee = kwargs.get("iteratee")
+    setter = kwargs.get("_setter")
+
+    if setter is None:
+        setter = base_set
 
     for source in sources:
-        # Don't re-clone if we've already cloned before.
-        if _clone:
-            source = copy.deepcopy(source)
-
         for key, src_value in iterator(source):
             obj_value = base_get(obj, key, default=None)
-            all_sequences = all([isinstance(src_value, list), isinstance(obj_value, list)])
-            all_mappings = all([isinstance(src_value, dict), isinstance(obj_value, dict)])
+            all_sequences = isinstance(src_value, list) and isinstance(obj_value, list)
+            all_mappings = isinstance(src_value, dict) and isinstance(obj_value, dict)
 
-            if cbk:
-                _result = cbk(obj_value, src_value, key, obj, source)
-            else:
-                _result = None
+            _result = None
+            if iteratee:
+                _result = iteratee(obj_value, src_value, key, obj, source)
 
             if _result is not None:
                 result = _result
             elif all_sequences or all_mappings:
-                result = merge_with(obj_value, src_value, _clone=False, _setter=setter)
+                result = _merge_with(obj_value, src_value, _setter=setter)
             else:
                 result = src_value
 
@@ -1155,7 +1164,7 @@ def rename_keys(obj, key_map):
 
     .. versionadded:: 2.0.0
     """
-    return {key_map.get(key, key): value for key, value in iteritems(obj)}
+    return {key_map.get(key, key): value for key, value in obj.items()}
 
 
 def set_(obj, path, value):
@@ -1402,7 +1411,7 @@ def to_list(obj, split_strings=True):
         return obj[:]
     elif isinstance(obj, dict):
         return obj.values()
-    elif not split_strings and (isinstance(obj, string_types) or isinstance(obj, bytes)):
+    elif not split_strings and isinstance(obj, (str, bytes)):
         return [obj]
     elif split_strings and isinstance(obj, bytes):
         # in python3 iterating over bytes gives integers instead of strings
@@ -1512,7 +1521,7 @@ def to_string(obj):
     elif obj is None:
         res = ""
     else:
-        res = text_type(obj)
+        res = str(obj)
     return res
 
 
@@ -1664,7 +1673,7 @@ def update_with(obj, path, updater, customizer=None):  # noqa: C901
                 _failed = True
 
             if _failed:
-                raise TypeError("Unable to update object at index {!r}. {}".format(key, exc))
+                raise TypeError(f"Unable to update object at index {key!r}. {exc}")
 
     value = base_get(target, last_key, default=None)
     base_set(target, last_key, callit(updater, value))
@@ -1723,14 +1732,14 @@ def unset(obj, path):  # noqa: C901
             except TypeError:
                 target = target[int(key)]
         except Exception:
-            target = NoValue
+            target = UNSET
 
-        if target is NoValue:
+        if target is UNSET:
             break
 
     did_unset = False
 
-    if target is not NoValue:
+    if target is not UNSET:
         try:
             try:
                 target.pop(last_key)
@@ -1778,7 +1787,7 @@ def values(obj):
 #
 
 
-def base_clone(value, is_deep=False, customizer=None, key=None, obj=None, _cloned=False):
+def base_clone(value, is_deep=False, customizer=None, key=None, _cloned=False):
     """Base clone function that supports deep clone and customizer callback."""
     clone_by = copy.deepcopy if is_deep else copy.copy
     result = None
@@ -1805,7 +1814,7 @@ def base_clone(value, is_deep=False, customizer=None, key=None, obj=None, _clone
     if cbk and not pyd.is_string(value) and not isinstance(value, bytes):
         for key, subvalue in iterator(value):
             if is_deep:
-                val = base_clone(subvalue, is_deep, cbk, key, value, _cloned=True)
+                val = base_clone(subvalue, is_deep, cbk, key, _cloned=True)
             else:
                 val = cbk(subvalue, key, value)
 
