@@ -1,28 +1,19 @@
-# -*- coding: utf-8 -*-
 """
 String functions.
 
 .. versionadded:: 1.1.0
 """
 
+import html
 import math
 import re
+import typing
 import unicodedata
+from urllib.parse import parse_qsl, urlencode, urlsplit, urlunsplit
 
 import pydash as pyd
 
-from ._compat import (
-    _range,
-    html_unescape,
-    iteritems,
-    parse_qsl,
-    text_type,
-    urlencode,
-    urlsplit,
-    urlunsplit,
-)
-from .helpers import NoValue
-from .objects import to_string
+from .helpers import UNSET
 
 
 __all__ = (
@@ -95,6 +86,40 @@ __all__ = (
 )
 
 
+class JSRegExp:
+    """
+    Javascript-style regular expression pattern.
+
+    Converts a Javascript-style regular expression to the equivalent Python version.
+    """
+
+    def __init__(self, reg_exp):
+        pattern, options = reg_exp[1:].rsplit("/", 1)
+
+        self._global = "g" in options
+        self._ignore_case = "i" in options
+
+        flags = re.I if self._ignore_case else 0
+        self.pattern = re.compile(pattern, flags=flags)
+
+    def find(self, text):
+        """Return list of regular expression matches."""
+        if self._global:
+            results = self.pattern.findall(text)
+        else:
+            res = self.pattern.search(text)
+            if res:
+                results = [res.group()]
+            else:
+                results = []
+        return results
+
+    def replace(self, text, repl):
+        """Replace parts of text that match the regular expression."""
+        count = 0 if self._global else 1
+        return self.pattern.sub(repl, text, count=count)
+
+
 HTML_ESCAPES = {"&": "&amp;", "<": "&lt;", ">": "&gt;", '"': "&quot;", "'": "&#39;", "`": "&#96;"}
 
 DEBURRED_LETTERS = {
@@ -165,12 +190,95 @@ DEBURRED_LETTERS = {
 }
 
 # Use Javascript style regex to make Lo-Dash compatibility easier.
-UPPER = "[A-Z\\xC0-\\xD6\\xD8-\\xDE]"
-LOWER = "[a-z\\xDf-\\xF6\\xF8-\\xFF]+"
-RE_WORDS = "/{upper}+(?={upper}{lower})|{upper}?{lower}|{upper}+|[0-9]+/g".format(
-    upper=UPPER, lower=LOWER
+# Lodash Regex definitions: https://github.com/lodash/lodash/blob/master/.internal/unicodeWords.js
+
+# References: https://github.com/lodash/lodash/blob/master/words.js#L8
+RS_ASCII_WORDS = "/[^\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]+/g"
+RS_LATIN1 = "/[\xC0-\xFF]/g"
+
+# Used to compose unicode character classes.
+RS_ASTRAL_RANGE = "\\ud800-\\udfff"
+RS_COMBO_MARKS_RANGE = "\\u0300-\\u036f"
+RE_COMBO_HALF_MARKS_RANGE = "\\ufe20-\\ufe2f"
+RS_COMBO_SYMBOLS_RANGE = "\\u20d0-\\u20ff"
+RS_COMBO_MARKS_EXTENDED_RANGE = "\\u1ab0-\\u1aff"
+RS_COMBO_MARKS_SUPPLEMENT_RANGE = "\\u1dc0-\\u1dff"
+RS_COMBO_RANGE = (
+    RS_COMBO_MARKS_RANGE
+    + RE_COMBO_HALF_MARKS_RANGE
+    + RS_COMBO_SYMBOLS_RANGE
+    + RS_COMBO_MARKS_EXTENDED_RANGE
+    + RS_COMBO_MARKS_SUPPLEMENT_RANGE
 )
-RE_LATIN1 = "/[\xC0-\xFF]/g"
+RS_DINGBAT_RANGE = "\\u2700-\\u27bf"
+RS_LOWER_RANGE = "a-z\\xdf-\\xf6\\xf8-\\xff"
+RS_MATH_OP_RANGE = "\\xac\\xb1\\xd7\\xf7"
+RS_NON_CHAR_RANGE = "\\x00-\\x2f\\x3a-\\x40\\x5b-\\x60\\x7b-\\xbf"
+RS_PUNCTUATION_RANGE = "\\u2000-\\u206f"
+RS_SPACE_RANGE = (
+    " \\t\\x0b\\f\\xa0\\ufeff\\n\\r\\u2028\\u2029\\"
+    "u1680\\u180e\\u2000\\u2001\\u2002\\u2003\\u2004\\u2005\\u2006\\"
+    "u2007\\u2008\\u2009\\u200a\\u202f\\u205f\\u3000"
+)
+RS_UPPER_RANGE = "A-Z\\xc0-\\xd6\\xd8-\\xde"
+RS_VAR_RANGE = "\\ufe0e\\ufe0f"
+RS_BREAK_RANGE = RS_MATH_OP_RANGE + RS_NON_CHAR_RANGE + RS_PUNCTUATION_RANGE + RS_SPACE_RANGE
+
+# Used to compose unicode capture groups.
+RS_APOS = "['\u2019]"
+RS_BREAK = f"[{RS_BREAK_RANGE}]"
+RS_COMBO = f"[{RS_COMBO_RANGE}]"
+RS_DIGIT = "\\d"
+RS_DINGBAT = f"[{RS_DINGBAT_RANGE}]"
+RS_LOWER = f"[{RS_LOWER_RANGE}]"
+RS_MISC = (
+    f"[^{RS_ASTRAL_RANGE}{RS_BREAK_RANGE}{RS_DIGIT}"
+    f"{RS_DINGBAT_RANGE}{RS_LOWER_RANGE}{RS_UPPER_RANGE}]"
+)
+RS_FITZ = "\\ud83c[\\udffb-\\udfff]"
+RS_MODIFIER = f"(?:{RS_COMBO}|{RS_FITZ})"
+RS_NON_ASTRAL = f"[^{RS_ASTRAL_RANGE}]"
+RS_REGIONAL = "(?:\\ud83c[\\udde6-\\uddff]){2}"
+RS_SURR_PAIR = "[\\ud800-\\udbff][\\udc00-\\udfff]"
+RS_UPPER = f"[{RS_UPPER_RANGE}]"
+RS_ZWJ = "\\u200d"
+
+# Used to compose unicode regexes.
+RS_MISC_LOWER = f"(?:{RS_LOWER}|{RS_MISC})"
+RS_MISC_UPPER = f"(?:{RS_UPPER}|{RS_MISC})"
+RS_OPT_CONTR_LOWER = f"(?:{RS_APOS}(?:d|ll|m|re|s|t|ve))?"
+RS_OPT_CONTR_UPPER = f"(?:{RS_APOS}(?:D|LL|M|RE|S|T|VE))?"
+RE_OPT_MOD = f"{RS_MODIFIER}?"
+RS_OPT_VAR = f"[{RS_VAR_RANGE}]?"
+RS_OPT_JOIN = (
+    f"(?:{RS_ZWJ}(?:{RS_NON_ASTRAL}|{RS_REGIONAL}|{RS_SURR_PAIR}){RS_OPT_VAR}{RE_OPT_MOD})*"
+)
+RS_ORD_LOWER = "\\d*(?:1st|2nd|3rd|(?![123])\\dth)(?=\\b|[A-Z_])"
+RS_ORD_UPPER = "\\d*(?:1ST|2ND|3RD|(?![123])\\dTH)(?=\\b|[a-z_])"
+RS_SEQ = RS_OPT_VAR + RE_OPT_MOD + RS_OPT_JOIN
+RS_EMOJI = f"(?:{RS_DINGBAT}|{RS_REGIONAL}|{RS_SURR_PAIR}){RS_SEQ}"
+
+RS_HAS_UNICODE_WORD = "[a-z][A-Z]|[A-Z]{2}[a-z]|[0-9][a-zA-Z]|[a-zA-Z][0-9]|[^a-zA-Z0-9 ]"
+RS_UNICODE_WORDS = (
+    f"/"
+    f"{RS_UPPER}?{RS_LOWER}+{RS_OPT_CONTR_LOWER}(?={RS_BREAK}|{RS_UPPER}|$)"
+    f"|{RS_MISC_UPPER}+{RS_OPT_CONTR_UPPER}(?={RS_BREAK}|{RS_UPPER}{RS_MISC_LOWER}|$)"
+    f"|{RS_UPPER}?{RS_MISC_LOWER}+{RS_OPT_CONTR_LOWER}"
+    f"|{RS_UPPER}+{RS_OPT_CONTR_UPPER}"
+    f"|{RS_ORD_UPPER}"
+    f"|{RS_ORD_LOWER}"
+    f"|{RS_DIGIT}+"
+    f"|{RS_EMOJI}"
+    f"/g"
+)
+
+# Compiled regexes for use in functions.
+JS_RE_ASCII_WORDS = JSRegExp(RS_ASCII_WORDS)
+JS_RE_UNICODE_WORDS = JSRegExp(RS_UNICODE_WORDS)
+JS_RE_LATIN1 = JSRegExp(RS_LATIN1)
+RE_HAS_UNICODE_WORD = re.compile(RS_HAS_UNICODE_WORD)
+RE_APOS = re.compile(RS_APOS)
+RE_HTML_TAGS = re.compile(r"<\/?[^>]+>")
 
 
 def camel_case(text):
@@ -189,8 +297,11 @@ def camel_case(text):
         'fooBarBAz'
 
     .. versionadded:: 1.1.0
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
-    text = "".join(word.title() for word in words(text))
+    text = "".join(word.title() for word in compounder(text))
     return text[:1].lower() + text[1:]
 
 
@@ -267,7 +378,7 @@ def chop(text, step):
     if step <= 0:
         chopped = [text]
     else:
-        chopped = [text[i : i + step] for i in _range(0, len(text), step)]
+        chopped = [text[i : i + step] for i in range(0, len(text), step)]
 
     return chopped
 
@@ -299,7 +410,7 @@ def chop_right(text, step):
         chopped = [text]
     else:
         text_len = len(text)
-        chopped = [text[-(i + step) : text_len - i] for i in _range(0, text_len, step)][::-1]
+        chopped = [text[-(i + step) : text_len - i] for i in range(0, text_len, step)][::-1]
 
     return chopped
 
@@ -371,10 +482,9 @@ def deburr(text):
 
     .. versionadded:: 2.0.0
     """
-    return reg_exp_js_replace(
-        pyd.to_string(text),
-        RE_LATIN1,
-        lambda match: DEBURRED_LETTERS.get(match.group(), match.group()),
+    text = pyd.to_string(text)
+    return JS_RE_LATIN1.replace(
+        text, lambda match: DEBURRED_LETTERS.get(match.group(), match.group())
     )
 
 
@@ -452,7 +562,9 @@ def ensure_ends_with(text, suffix):
     """
     text = pyd.to_string(text)
     suffix = pyd.to_string(suffix)
-    return text if text.endswith(suffix) else "{0}{1}".format(text, suffix)
+    if text.endswith(suffix):
+        return text
+    return f"{text}{suffix}"
 
 
 def ensure_starts_with(text, prefix):
@@ -462,7 +574,7 @@ def ensure_starts_with(text, prefix):
 
     Args:
         text (str): Source string to prepend `prefix` to.
-        suffix (str): String to prepend to the source string if the source string does not start
+        prefix (str): String to prepend to the source string if the source string does not start
             with `prefix`.
 
     Returns:
@@ -479,7 +591,9 @@ def ensure_starts_with(text, prefix):
     """
     text = pyd.to_string(text)
     prefix = pyd.to_string(prefix)
-    return text if text.startswith(prefix) else "{1}{0}".format(text, prefix)
+    if text.startswith(prefix):
+        return text
+    return f"{prefix}{text}"
 
 
 def escape(text):
@@ -504,8 +618,8 @@ def escape(text):
         Moved function to :mod:`pydash.strings`.
     """
     text = pyd.to_string(text)
-    # NOTE: Not using _compat.html_escape because Lo-Dash escapes certain chars differently (e.g.
-    # "'" isn't escaped by html_escape() but is by Lo-Dash).
+    # NOTE: Not using html.escape because Lo-Dash escapes certain chars differently (e.g. "'" isn't
+    # escaped by html.escape() but is by Lo-Dash).
     return "".join(HTML_ESCAPES.get(char, char) for char in text)
 
 
@@ -577,6 +691,9 @@ def human_case(text):
         'User'
 
     .. versionadded:: 3.0.0
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
     return (
         pyd.chain(text)
@@ -656,8 +773,11 @@ def kebab_case(text):
         'a-b-c-d-e-f'
 
     .. versionadded:: 1.1.0
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
-    return separator_case(text, "-")
+    return "-".join(word.lower() for word in compounder(text) if word)
 
 
 def lines(text):
@@ -700,8 +820,11 @@ def lower_case(text):
         'foo 10 b ar'
 
     .. versionadded:: 4.0.0
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
-    return " ".join(words(text)).lower()
+    return " ".join(compounder(text)).lower()
 
 
 def lower_first(text):
@@ -753,7 +876,7 @@ def number_format(number, scale=0, decimal_separator=".", order_separator=","):
     .. versionadded:: 3.0.0
     """
     # Create a string formatter which converts number to the appropriately scaled representation.
-    fmt = "{{0:.{0:d}f}}".format(scale)
+    fmt = f"{{0:.{scale:d}f}}"
 
     try:
         num_parts = fmt.format(number).split(".")
@@ -898,6 +1021,9 @@ def pascal_case(text, strict=True):
         'FooBarBAz'
 
     .. versionadded:: 3.0.0
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
     text = pyd.to_string(text)
 
@@ -1047,7 +1173,7 @@ def reg_exp_js_match(text, reg_exp):
         Renamed from ``js_match`` to ``reg_exp_js_match``.
     """
     text = pyd.to_string(text)
-    return js_to_py_re_find(reg_exp)(text)
+    return JSRegExp(reg_exp).find(text)
 
 
 def reg_exp_js_replace(text, reg_exp, repl):
@@ -1057,7 +1183,7 @@ def reg_exp_js_replace(text, reg_exp, repl):
     Args:
         text (str): String to evaluate.
         reg_exp (str): Javascript style regular expression.
-        repl (str): Replacement string.
+        repl (str|callable): Replacement string or callable.
 
     Returns:
         str: Modified string.
@@ -1084,7 +1210,7 @@ def reg_exp_js_replace(text, reg_exp, repl):
     text = pyd.to_string(text)
     if not pyd.is_function(repl):
         repl = pyd.to_string(repl)
-    return js_to_py_reg_exp_replace(reg_exp)(text, repl)
+    return JSRegExp(reg_exp).replace(text, repl)
 
 
 def reg_exp_replace(text, pattern, repl, ignore_case=False, count=0):
@@ -1094,7 +1220,7 @@ def reg_exp_replace(text, pattern, repl, ignore_case=False, count=0):
 
     Args:
         text (str): String to replace.
-        pattern (str): String pattern to find and replace.
+        pattern (str|typing.Pattern): Pattern to find and replace.
         repl (str): String to substitute `pattern` with.
         ignore_case (bool, optional): Whether to ignore case when replacing. Defaults to ``False``.
         count (int, optional): Maximum number of occurrences to replace. Defaults to ``0`` which
@@ -1155,7 +1281,7 @@ def replace(
 
     Args:
         text (str): String to replace.
-        pattern (str): String pattern to find and replace.
+        pattern (str|typing.Pattern): Pattern to find and replace.
         repl (str): String to substitute `pattern` with.
         ignore_case (bool, optional): Whether to ignore case when replacing. Defaults to ``False``.
         count (int, optional): Maximum number of occurrences to replace. Defaults to ``0`` which
@@ -1186,29 +1312,37 @@ def replace(
 
     .. versionchanged:: 4.1.0
         Added ``from_start`` and ``from_end`` arguments.
+
+    .. versionchanged:: 5.0.0
+        Added support for ``pattern`` as ``typing.Pattern`` object.
     """
     text = pyd.to_string(text)
 
     if pattern is None:
         return text
 
-    pattern = pyd.to_string(pattern)
-
-    if escape:
-        pattern = re.escape(pattern)
-
-    if from_start and not pattern.startswith("^"):
-        pattern = "^" + pattern
-
-    if from_end and not pattern.endswith("$"):
-        pattern += "$"
-
     if not pyd.is_function(repl):
         repl = pyd.to_string(repl)
 
     flags = re.IGNORECASE if ignore_case else 0
 
-    return re.sub(pattern, repl, text, count=count, flags=flags)
+    if isinstance(pattern, typing.Pattern):
+        pat = pattern
+    else:
+        pattern = pyd.to_string(pattern)
+
+        if escape:
+            pattern = re.escape(pattern)
+
+        if from_start and not pattern.startswith("^"):
+            pattern = "^" + pattern
+
+        if from_end and not pattern.endswith("$"):
+            pattern += "$"
+
+        pat = re.compile(pattern, flags=flags)
+
+    return pat.sub(repl, text, count=count)
 
 
 def replace_end(text, pattern, repl, ignore_case=False, escape=True):
@@ -1218,7 +1352,7 @@ def replace_end(text, pattern, repl, ignore_case=False, escape=True):
 
     Args:
         text (str): String to replace.
-        pattern (str): String pattern to find and replace.
+        pattern (str|typing.Pattern): Pattern to find and replace.
         repl (str): String to substitute `pattern` with.
         ignore_case (bool, optional): Whether to ignore case when replacing. Defaults to ``False``.
         escape (bool, optional): Whether to escape `pattern` when searching. This is needed if a
@@ -1247,9 +1381,9 @@ def replace_start(text, pattern, repl, ignore_case=False, escape=True):
 
     Args:
         text (str): String to replace.
-        pattern (str): String pattern to find and replace.
+        pattern (str|typing.Pattern): Pattern to find and replace.
         repl (str): String to substitute `pattern` with.
-        ignore_clase (bool, optional): Whether to ignore case when replacing. Defaults to ``False``.
+        ignore_case (bool, optional): Whether to ignore case when replacing. Defaults to ``False``.
         escape (bool, optional): Whether to escape `pattern` when searching. This is needed if a
             literal replacement is desired when `pattern` may contain special regular expression
             characters. Defaults to ``True``.
@@ -1286,6 +1420,9 @@ def separator_case(text, separator):
         'a-b-c-d'
 
     .. versionadded:: 3.0.0
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
     return separator.join(word.lower() for word in words(text) if word)
 
@@ -1377,11 +1514,12 @@ def slugify(text, separator="-"):
         True
 
     .. versionadded:: 3.0.0
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
     normalized = (
-        unicodedata.normalize("NFKD", text_type(pyd.to_string(text)))
-        .encode("ascii", "ignore")
-        .decode("utf8")
+        unicodedata.normalize("NFKD", pyd.to_string(text)).encode("ascii", "ignore").decode("utf8")
     )
 
     return separator_case(normalized, separator)
@@ -1406,11 +1544,14 @@ def snake_case(text):
 
     .. versionchanged:: 4.0.0
         Removed alias ``underscore_case``.
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
-    return separator_case(text, "_")
+    return "_".join(word.lower() for word in compounder(text) if word)
 
 
-def split(text, separator=NoValue):
+def split(text, separator=UNSET):
     """
     Splits `text` on `separator`. If `separator` not provided, then `text` is split on whitespace.
     If `separator` is falsey, then `text` is split on every character.
@@ -1439,7 +1580,7 @@ def split(text, separator=NoValue):
     """
     text = pyd.to_string(text)
 
-    if separator is NoValue:
+    if separator is UNSET:
         ret = text.split()
     elif separator:
         ret = text.split(separator)
@@ -1465,9 +1606,11 @@ def start_case(text):
         'Foo Bar'
 
     .. versionadded:: 3.1.0
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
-    text = pyd.to_string(text)
-    return " ".join(capitalize(word, strict=False) for word in words(text))
+    return " ".join(capitalize(word, strict=False) for word in compounder(text))
 
 
 def starts_with(text, target, position=0):
@@ -1515,7 +1658,7 @@ def strip_tags(text):
 
     .. versionadded:: 3.0.0
     """
-    return reg_exp_replace(text, r"<\/?[^>]+>", "")
+    return RE_HTML_TAGS.sub("", pyd.to_string(text))
 
 
 def substr_left(text, subtext):
@@ -1655,7 +1798,9 @@ def surround(text, wrapper):
 
     .. versionadded:: 2.4.0
     """
-    return "{1}{0}{1}".format(pyd.to_string(text), pyd.to_string(wrapper))
+    text = pyd.to_string(text)
+    wrapper = pyd.to_string(wrapper)
+    return f"{wrapper}{text}{wrapper}"
 
 
 def swap_case(text):
@@ -1722,7 +1867,7 @@ def to_lower(text):
 
     .. versionadded:: 4.0.0
     """
-    return to_string(text).lower()
+    return pyd.to_string(text).lower()
 
 
 def to_upper(text):
@@ -1746,7 +1891,7 @@ def to_upper(text):
 
     .. versionadded:: 4.0.0
     """
-    return to_string(text).upper()
+    return pyd.to_string(text).upper()
 
 
 def trim(text, chars=None):
@@ -1899,7 +2044,7 @@ def unescape(text):
         Moved to :mod:`pydash.strings`.
     """
     text = pyd.to_string(text)
-    return html_unescape(text)
+    return html.unescape(text)
 
 
 def upper_case(text):
@@ -1922,8 +2067,11 @@ def upper_case(text):
         'FOO 10 B AR'
 
     .. versionadded:: 4.0.0
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
-    return " ".join(words(text)).upper()
+    return " ".join(compounder(text)).upper()
 
 
 def upper_first(text):
@@ -1958,6 +2106,7 @@ def unquote(text, quote_char='"'):
 
     Args:
         text (str): String to unquote.
+        quote_char (str, optional): Quote character to remove. Defaults to `"`.
 
     Returns:
         str: Unquoted string.
@@ -1978,7 +2127,7 @@ def unquote(text, quote_char='"'):
     text = pyd.to_string(text)
     inner = text[1:-1]
 
-    if text == "{0}{1}{0}".format(quote_char, inner):
+    if text == f"{quote_char}{inner}{quote_char}":
         text = inner
 
     return text
@@ -2030,6 +2179,9 @@ def words(text, pattern=None):
     """
     Return list of words contained in `text`.
 
+    References:
+        https://github.com/lodash/lodash/blob/master/words.js#L30
+
     Args:
         text (str): String to split.
         pattern (str, optional): Custom pattern to split words on. Defaults to ``None``.
@@ -2051,8 +2203,19 @@ def words(text, pattern=None):
 
     .. versionchanged:: 3.2.0
         Improved matching for one character words.
+
+    .. versionchanged:: 5.0.0
+        Improved unicode word support.
     """
-    return reg_exp_js_match(text, pattern or RE_WORDS)
+    text = pyd.to_string(text)
+    if pattern is None:
+        if has_unicode_word(text):
+            reg_exp = JS_RE_UNICODE_WORDS
+        else:
+            reg_exp = JS_RE_ASCII_WORDS
+    else:
+        reg_exp = JSRegExp(pattern)
+    return reg_exp.find(text)
 
 
 #
@@ -2060,37 +2223,27 @@ def words(text, pattern=None):
 #
 
 
-def js_to_py_re_find(reg_exp):
-    """Return Python regular expression matching function based on Javascript style regexp."""
-    pattern, options = reg_exp[1:].rsplit("/", 1)
-    flags = re.I if "i" in options else 0
+def compounder(text):
+    """
+    Remove single quote before passing into words() to match Lodash-style outputs.
 
-    def find(text):
-        if "g" in options:
-            results = re.findall(pattern, text, flags=flags)
-        else:
-            results = re.search(pattern, text, flags=flags)
+    Required by certain functions such as kebab_case, camel_case, start_case etc.
 
-            if results:
-                results = [results.group()]
-            else:
-                results = []
-
-        return results
-
-    return find
+    References:
+        https://github.com/lodash/lodash/blob/4.17.15/lodash.js#L4968
+    """
+    return words(deburr(RE_APOS.sub("", pyd.to_string(text))))
 
 
-def js_to_py_reg_exp_replace(reg_exp):
-    """Return Python regular expression substitution function based on Javascript style regexp."""
-    pattern, options = reg_exp[1:].rsplit("/", 1)
-    count = 0 if "g" in options else 1
-    ignore_case = "i" in options
+def has_unicode_word(text):
+    """
+    Check if the text contains unicode or requires more complex regex to handle.
 
-    def _replace(text, repl):
-        return reg_exp_replace(text, pattern, repl, ignore_case=ignore_case, count=count)
-
-    return _replace
+    References:
+        https://github.com/lodash/lodash/blob/master/words.js#L3
+    """
+    result = RE_HAS_UNICODE_WORD.search(text)
+    return bool(result)
 
 
 def delimitedpathjoin(delimiter, *paths):
@@ -2137,7 +2290,7 @@ def flatten_url_params(params):
     >>> assert flatten_url_params(params) == [('a', 1), ('a', 2), ('a', 3)]
     """
     if isinstance(params, dict):
-        params = list(iteritems(params))
+        params = list(params.items())
 
     flattened = []
     for param, value in params:
