@@ -1,15 +1,16 @@
-# -*- coding: utf-8 -*-
-
 from argparse import Namespace
 from collections import defaultdict, namedtuple
 import datetime as dt
 
+import pytest
+
 import pydash as _
 
 from . import fixtures
-from .fixtures import parametrize
 
 
+parametrize = pytest.mark.parametrize
+
 today = dt.date.today()
 
 
@@ -535,6 +536,14 @@ def test_map_values_deep(case, expected):
             },
         ),
         (({"foo": {"bar": 1}}, {"foo": {}}), {"foo": {"bar": 1}}),
+        (({},), {}),
+        (([],), []),
+        ((None,), None),
+        ((None, {"a": 1}), None),
+        ((None, None, None, {"a": 1}), None),
+        (({"a": 1}, None), {"a": 1}),
+        (({"a": 1}, None, None, None, {"b": 2}), {"a": 1, "b": 2}),
+        (({"a": None}, None, None, None, {"b": None}), {"a": None, "b": None}),
     ],
 )
 def test_merge(case, expected):
