@@ -1,14 +1,13 @@
-# -*- coding: utf-8 -*-
-
 import re
 import sys
+from urllib.parse import parse_qsl, urlsplit
 
 import pytest
 
 import pydash as _
-from pydash._compat import parse_qsl, urlsplit
 
-from .fixtures import parametrize
+
+parametrize = pytest.mark.parametrize
 
 
 @parametrize(
@@ -20,6 +19,18 @@ from .fixtures import parametrize
         ("foo-_bar-_-baz", "fooBarBaz"),
         ("foo!bar,baz", "fooBarBaz"),
         ("--foo.bar;baz", "fooBarBaz"),
+        ("Foo!#Bar's", "fooBars"),
+        ("你好,世界", "你好世界"),
+        ("你好 世界", "你好世界"),
+        ("你好(世界)", "你好世界"),
+        ("你好（世界）", "你好（世界）"),
+        ("你好，世界", "你好，世界"),
+        ("Σὲ γνωρίζω ἀπὸ τὴν κόψη", "σὲΓνωρίζωἈπὸΤὴνΚόψη"),
+        ("แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช", "แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช"),
+        ("いろはにほへど　ちりぬるを", "いろはにほへどちりぬるを"),
+        ("나는 유리를 먹을 수 있어요. 그래도 아프지 않아요", "나는유리를먹을수있어요그래도아프지않아요"),
+        ("J'peux manger d'la vitre, ça m'fa pas mal.", "jpeuxMangerDlaVitreCaMfaPasMal"),
+        ("e peux manger du verre, ça ne me fait pas mal.", "ePeuxMangerDuVerreCaNeMeFaitPasMal"),
         (8, "8"),
         ("", ""),
         (None, ""),
@@ -376,6 +387,18 @@ def test_join(case, expected):
         ("--foo.bar;baz", "foo-bar-baz"),
         ("Foo Bar", "foo-bar"),
         ("fooBar", "foo-bar"),
+        ("你好,世界", "你好-世界"),
+        ("你好(世界)", "你好-世界"),
+        ("你好（世界）", "你好（世界）"),
+        ("Σὲ γνωρίζω ἀπὸ τὴν κόψη", "σὲ-γνωρίζω-ἀπὸ-τὴν-κόψη"),
+        ("แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช", "แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช"),
+        ("いろはにほへど　ちりぬるを", "いろはにほへど-ちりぬるを"),
+        ("나는 유리를 먹을 수 있어요. 그래도 아프지 않아요", "나는-유리를-먹을-수-있어요-그래도-아프지-않아요"),
+        ("J'peux manger d'la vitre, ça m'fa pas mal.", "jpeux-manger-dla-vitre-ca-mfa-pas-mal"),
+        (
+            "e peux manger du verre, ça ne me fait pas mal.",
+            "e-peux-manger-du-verre-ca-ne-me-fait-pas-mal",
+        ),
         (None, ""),
         (5, "5"),
         (5.6, "5-6"),
@@ -646,6 +669,7 @@ def test_repeat(case, expected):
     "case,expected",
     [
         (("foo", "o", "a"), "faa"),
+        (("foo", re.compile("o"), "a"), "faa"),
         (("foo", "o", "a", False, 1), "fao"),
         (("fOO", "o", "a"), "fOO"),
         (("fOO", "o", "a", True), "faa"),
@@ -784,6 +808,19 @@ def test_slugify(case, expected):
         ("--foo.bar;baz", "foo_bar_baz"),
         ("FooBar", "foo_bar"),
         ("fooBar", "foo_bar"),
+        ("你好,世界", "你好_世界"),
+        ("你好(世界)", "你好_世界"),
+        ("你好（世界）", "你好（世界）"),
+        ("你好，世界", "你好，世界"),
+        ("Σὲ γνωρίζω ἀπὸ τὴν κόψη", "σὲ_γνωρίζω_ἀπὸ_τὴν_κόψη"),
+        ("แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช", "แผ่นดินฮั่นเสื่อมโทรมแสนสังเวช"),
+        ("いろはにほへど　ちりぬるを", "いろはにほへど_ちりぬるを"),
+        ("나는 유리를 먹을 수 있어요. 그래도 아프지 않아요", "나는_유리를_먹을_수_있어요_그래도_아프지_않아요"),
+        ("J'peux manger d'la vitre, ça m'fa pas mal.", "jpeux_manger_dla_vitre_ca_mfa_pas_mal"),
+        (
+            "e peux manger du verre, ça ne me fait pas mal.",
+            "e_peux_manger_du_verre_ca_ne_me_fait_pas_mal",
+        ),
         ("", ""),
         (None, ""),
         (5, "5"),
@@ -814,7 +851,7 @@ def test_split(case, expected):
     [
         ("foo bar baz", "Foo Bar Baz"),
         ("foo-bar-baz", "Foo Bar Baz"),
-        ("Foo!#Bar's", "Foo Bar S"),
+        ("Foo!#Bar's", "Foo Bars"),
         ("fooBar", "Foo Bar"),
         ("___FOO-BAR___", "FOO BAR"),
         ("XMLHttp", "XML Http"),
