@@ -1,13 +1,18 @@
-# -*- coding: utf-8 -*-
-
 import time
+from unittest import mock
 
-import mock
 import pytest
 
 import pydash as _
 
-from .fixtures import mocked_sleep, parametrize
+
+parametrize = pytest.mark.parametrize
+
+
+@pytest.fixture
+def mocked_sleep():
+    with mock.patch("time.sleep") as mocked:
+        yield mocked
 
 
 @parametrize("case,expected", [((lambda a, b: a / b, 4, 2), 2)])
